@@ -13,24 +13,24 @@
 
 dburr <- function (x, shape1, shape2, rate = 1, scale = 1/rate,
                    log = FALSE)
-    .External("do_dpq", "dburr", x, shape1, shape2, scale, log)
+    .External("actuar_do_dpq", "dburr", x, shape1, shape2, scale, log)
 
 pburr <- function(q, shape1, shape2, rate = 1, scale = 1/rate,
                   lower.tail = TRUE, log.p = FALSE)
-    .External("do_dpq", "pburr", q, shape1, shape2, scale,
+    .External("actuar_do_dpq", "pburr", q, shape1, shape2, scale,
               lower.tail, log.p)
 
 qburr <- function(p, shape1, shape2, rate = 1, scale = 1/rate,
                   lower.tail = TRUE, log.p = FALSE)
-    .External("do_dpq", "qburr", p, shape1, shape2, scale,
+    .External("actuar_do_dpq", "qburr", p, shape1, shape2, scale,
               lower.tail, log.p)
 
 rburr <- function(n, shape1, shape2, rate = 1, scale = 1/rate)
-    .External("do_random", "rburr", n, shape1, shape2, scale)
+    .External("actuar_do_random", "rburr", n, shape1, shape2, scale)
 
 mburr <- function(order, shape1, shape2, rate = 1, scale = 1/rate)
-    .External("do_dpq", "mburr", order, shape1, shape2, scale, FALSE)
+    .External("actuar_do_dpq", "mburr", order, shape1, shape2, scale, FALSE)
 
 levburr <- function(limit, shape1, shape2, rate = 1, scale = 1/rate,
                     order = 1)
-    .External("do_dpq", "levburr", limit, shape1, shape2, scale, order, FALSE)
+    .External("actuar_do_dpq", "levburr", limit, shape1, shape2, scale, order, FALSE)
