@@ -17,7 +17,7 @@ elev.default <- function(x, ...)
     if (!exists("Call", inherits = FALSE))
         Call <- match.call()
     FUN <- function(limit)
-        colMeans(sapply(limit, pmin, x = x))
+        sapply(limit, function(x, y) mean(pmin(x, y)), x = x)
     environment(FUN) <- new.env()
     assign("x", sort(x), envir = environment(FUN))
     assign("n", length(unique(x)), envir = environment(FUN))
